from masint.util.make_api_url import make_api_url

import aiohttp
import asyncio

import logging

logger = logging.getLogger(__name__)


def squeue():
    logger.info(f"Getting squeue")

    try:
        asyncio.run(squeue_async())
    except Exception as e:
        logger.error(f"Failed to get squeue output")
        logger.error(e)


async def squeue_async():
    async with aiohttp.ClientSession() as session:
        async with session.get(make_api_url(f"v1/megatron/squeue")) as resp:
            data = await resp.json()

            logger.info(f"Got response for squeue")
            logger.info(data)

            if resp.status != 200:
                logger.error(f"Failed to get squeue")
                logger.error(data)
                raise Exception("Failed to get squeue")

            print(data["squeue_output"])




from masint import SupermassiveIntelligence

import logging

logger = logging.getLogger(__name__)


def ls():
    logger.debug(f"Listing models")

    try:
        llm = SupermassiveIntelligence()

        models = llm.list_models()
    except Exception as e:
        logger.error(f"Failed to list models")
        logger.error(e)

    print_models(models["models"])


def print_models(models):
    for model in models:
        print(model)



import masint

import os

def get_api_base():
    if masint.api_url is not None:
        return masint.api_url

    if "MASINT_API_URL" in os.environ:
        return os.environ["MASINT_API_URL"]

    return "http://localhost:8000"




from masint.cli.view_logs import view_logs
from masint.cli.plot import plot
from masint.cli.ls import ls
from masint.cli.squeue import squeue

import masint

from argparse import ArgumentParser

import logging

logger = logging.getLogger(__name__)


def main():
    setup_logging()

    argumments, parser = parse_arguments()

    if argumments.command == "logs":
        view_logs(
            model_name=argumments.model,
            tail=argumments.tail,
            lines=argumments.lines,
            follow=argumments.follow,
        )

    elif argumments.command == "plot":
        plot(model_name=argumments.model, smooth=int(argumments.smooth))

    elif argumments.command == "ls":
        ls()

    elif argumments.command == "squeue":
        squeue()

    else:
        logger.error(f"Unknown command {argumments.command}")
        parser.print_help()
        exit(1)


def setup_logging():
    logging.basicConfig(level=logging.WARNING)

    logging.getLogger("matplotlib").setLevel(logging.WARNING)
    logging.getLogger("asyncio").setLevel(logging.WARNING)


def parse_arguments():
    parser = ArgumentParser(description="The command line interface for MasInt ScalarLM")

    # Add a subparser for the 'logs' command
    subparsers = parser.add_subparsers(dest="command")

    add_logs_parser(subparsers)
    add_plot_parser(subparsers)
    add_ls_parser(subparsers)
    add_squeue_parser(subparsers)

    args = parser.parse_args()

    return args, parser


def add_logs_parser(subparsers):
    logs_parser = subparsers.add_parser("logs", help="View logs")
    logs_parser.add_argument("--model", help="The model to view logs for", default="latest")
    logs_parser.add_argument(
        "--tail",
        help="Whether to tail the logs",
        default=False,
        action="store_true",
    )
    logs_parser.add_argument(
        "--follow",
        "-f",
        help="Whether to follow the logs",
        default=False,
        action="store_true",
    )

    logs_parser.add_argument(
        "--lines", type=int, help="The number of lines to view", default=100
    )


def add_plot_parser(subparsers):
    plot_parser = subparsers.add_parser("plot", help="Plot the results of a model")

    plot_parser.add_argument("--model", help="The model to plot results for", default="latest")
    plot_parser.add_argument("--smooth", help="The number of steps to smooth over", default=1)


def add_ls_parser(subparsers):
    ls_parser = subparsers.add_parser("ls", help="List models")


def add_squeue_parser(subparsers):
    squeue_parser = subparsers.add_parser("squeue", help="View the squeue")


if __name__ == "__main__":
    main()
